@@ -2,7 +2,7 @@ package MooseX::App::Cmd::Command::BashComplete;
 use Moose;
 extends 'MooseX::App::Cmd::Command';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use MooseX::Getopt;
 
@@ -21,61 +21,63 @@ sub execute {
 
     my $cmd_list = join ' ', @commands;
     my $package  = __PACKAGE__;
+    my $prefix = $self->app->arg0;
+    $prefix =~ tr/./_/;
 
     print <<"EOT";
 #!/bin/bash
 
 # Built with $package;
 
-COMMANDS='help commands bashcomplete $cmd_list'
+${prefix}_COMMANDS='help commands bashcomplete $cmd_list'
 
-_macc_help() {
+_${prefix}_macc_help() {
     if [ \$COMP_CWORD = 2 ]; then
-        _compreply "\$COMMANDS"
+        _${prefix}_compreply "\$${prefix}_COMMANDS"
     else
         COMPREPLY=()
     fi
 }
 
-_macc_commands() {
+_${prefix}_macc_commands() {
     COMPREPLY=()
 }
 
-_macc_bashcomplete() {
+_${prefix}_macc_bashcomplete() {
     COMPREPLY=()
 }
 
 EOT
 
     while (my ($c, $o) = each %command_map) {
-        print "_macc_$c() {\n    _compreply \"",
+        print "_${prefix}_macc_$c() {\n    _compreply \"",
             join(" ", map {"--" . $_->{name}} @$o),
                 "\"\n}\n\n";
     }
 
 
-print <<'EOT';
+print <<"EOT";
 
-_compreply() {
-    COMPREPLY=($(compgen -W "$1" -- ${COMP_WORDS[COMP_CWORD]}))
+_${prefix}_compreply() {
+    COMPREPLY=(\$(compgen -W "\$1" -- \${COMP_WORDS[COMP_CWORD]}))
 }
 
-_macc() {
-    case $COMP_CWORD in
+_${prefix}_macc() {
+    case \$COMP_CWORD in
         0)
             ;;
         1)
-            _compreply "$COMMANDS"
+            _${prefix}_compreply "\$${prefix}_COMMANDS"
             ;;
         *)
-            eval _macc_${COMP_WORDS[1]}
+            eval _${prefix}_macc_\${COMP_WORDS[1]}
             
     esac
 }
 
 EOT
 
-    print "complete -o default -F _macc ", $self->app->arg0, "\n";
+    print "complete -o default -F _${prefix}_macc ", $self->app->arg0, "\n";
 }
 
 
@@ -89,7 +91,7 @@ MooseX::App::Cmd::Command::BashComplete - Bash completion for your MooseX::App::
 
 =head1 VERSION
 
-Version 0.01
+Version 0.03
 
 
 =head1 SYNOPSIS
